@@ -6,8 +6,6 @@
 
 #include <KI18n/KLocalizedString>
 
-#include "../nota_version.h"
-
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
 #include <MauiKit/Core/mauiandroid.h>
@@ -18,6 +16,7 @@
 #include <MauiKit/Core/mauiapp.h>
 
 #include "nota.h"
+#include "../nota_version.h"
 
 // Models
 #include "models/historymodel.h"
@@ -42,12 +41,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/img/nota.svg"));
 
-    MauiApp::instance()->setHandleAccounts(false); // for now nota can not handle cloud accounts
     MauiApp::instance()->setIconName("qrc:/img/nota.svg");
 
     KLocalizedString::setApplicationDomain("nota");
 
-    KAboutData about(QStringLiteral("nota"), i18n("Nota"), NOTA_VERSION_STRING, i18n("Nota allows you to browse, create, and edit simple and rich text files."), KAboutLicense::LGPL_V3,i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("nota"), i18n("Nota"), NOTA_VERSION_STRING, i18n("Browse, create and edit text files."), KAboutLicense::LGPL_V3,i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.addAuthor(i18n("Anupam Basak"), i18n("Developer"), QStringLiteral("anupam.basak27@gmail.com"));
@@ -82,8 +80,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     Qt::QueuedConnection);
 
     qmlRegisterSingletonInstance<Nota>(NOTA_URI, 1, 0, "Nota", Nota::instance());
-    qmlRegisterType<HistoryModel>(NOTA_URI, 1, 0, "History");
-
+    qmlRegisterSingletonType<HistoryModel>(NOTA_URI, 1, 0, "History", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
+        Q_UNUSED(scriptEngine)
+        Q_UNUSED(engine)
+           return new HistoryModel;
+       });
     engine.load(url);
 
     return app.exec();
